TurboEncab

Struct TurboEncab 

pub struct TurboEncab<'io, IO = PtrIO> { /* private fields */ }
Turbo-Encabulator

Configuration & status address space for the state-of-the-art Turbo Encabulator. It is strongly recommended that users of the Turbo Encabulator watch the training video prior to attempting to supply inverse reactive current. The product brief for Rockwell Automation’s Retro Encabulator is also a sufficient substitute.

Implementations

Source

impl TurboEncab<'static>

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

Safety

The caller must guarantee that the provided address points to a hardware register block implementing this interface.

Source

impl<'io, IO> TurboEncab<'io, IO>

pub const SIZE: usize = 10_468usize

Size in bytes of the underlying memory

pub const unsafe fn from_ptr_with(ptr: *mut (), io: &'io IO) -> Self

Safety

The caller must guarantee that the provided address points to a hardware register block implementing this interface.

pub const fn as_ptr(&self) -> *mut ()

Source

impl<'io, IO: RegisterIO> TurboEncab<'io, IO>

pub const fn ctrl(&self) -> Reg<'io, Ctrl, IO>

System Control Register

pub const fn status(&self) -> Reg<'io, Status, IO>

Encabulator Status

pub const fn grammeter(&self) -> [Grammeter<'io, IO>; 12]

Cardinal Grammeter

The Turbo Encabulator contains twelve cardinal grammeters. Each has the following features:

  • Automatically synchronizing.
  • Fully independent of the five dingle arms.
  • Produces reliable entropic measurements.
pub const fn measurements(&self) -> Measurements<'io, IO>

Historical Antigravitic Marzelvane Measurements

Marzelvane measurements have a drift of less than 3 ft^2-hrs/mo.